@@ -158,6 +158,13 @@ build_launch_environment (GdmLaunchEnvironment *launch_environment,
         if (launch_environment->priv->session_mode != NULL)
                 g_hash_table_insert (hash, g_strdup ("GNOME_SHELL_SESSION_MODE"), g_strdup (launch_environment->priv->session_mode));
 
+        /* Inital setup needs gvfs for fetching remote avatars. */
+        if (strcmp (launch_environment->priv->session_mode, INITIAL_SETUP_SESSION_MODE) != 0) {
+                g_hash_table_insert (hash, g_strdup ("GVFS_DISABLE_FUSE"), g_strdup ("1"));
+                g_hash_table_insert (hash, g_strdup ("GIO_USE_VFS"), g_strdup ("local"));
+                g_hash_table_insert (hash, g_strdup ("GVFS_REMOTE_VOLUME_MONITOR_IGNORE"), g_strdup ("1"));
+        }
+
         g_hash_table_insert (hash, g_strdup ("LOGNAME"), g_strdup (launch_environment->priv->user_name));
         g_hash_table_insert (hash, g_strdup ("USER"), g_strdup (launch_environment->priv->user_name));
         g_hash_table_insert (hash, g_strdup ("USERNAME"), g_strdup (launch_environment->priv->user_name));
@@ -862,7 +869,7 @@ create_gnome_session_environment (const char *session_id,
         gdm_settings_direct_get_boolean (GDM_KEY_DEBUG, &debug);
 
         args = g_ptr_array_new ();
-        g_ptr_array_add (args, BINDIR "/gnome-session");
+        g_ptr_array_add (args, "gnome-session");
 
         g_ptr_array_add (args, "--autostart");
         g_ptr_array_add (args, DATADIR "/gdm/greeter/autostart");
