@@ -24,6 +24,7 @@
 #include <glib-object.h>
 
 #include "s-common-address.h"
+#include "s-common.h"
 
 static gboolean no_fork = FALSE;
 static gboolean verbose = FALSE;
@@ -66,5 +67,15 @@ main (int argc, char **argv)
         failed = srunner_ntests_failed (r);
         srunner_free (r);
 
+        r = srunner_create (suite_common ());
+
+        if (no_fork) {
+                srunner_set_fork_status (r, CK_NOFORK);
+        }
+
+        srunner_run_all (r, verbose ? CK_VERBOSE : CK_NORMAL);
+        failed |= srunner_ntests_failed (r);
+        srunner_free (r);
+
         return failed != 0;
 }
